#!/usr/bin/env python
#
# grib_checker.py checks Checks whatever you want to check in your life
#
# AUTHOR: BSC-CNS I. CERNICHARO
#

import sys
import numpy as np
from eccodes import GribFile

import data_checks
import metadata_checks

class grib_content:
    
    def __init__(self,filename):
        self.name = filename
        self.grib_content = GribFile(self.name)
        self.pname = filename.split("/")[-1]

    def print_num_keys(self):
        return self.pname+" has "+str(len(self.grib_content))+" messages"

    def check_data_coords(self):
        coords_log = list()
        data_log = list()
        index = list()

        for i,msg in enumerate(self.grib_content):
            coords_log.append(data_checks.check_coords(msg))
            data_log.append(data_checks.check_data_values(msg))
            index.append(i)
        
        err_coords = coords_log.count("ERROR")
        err_data = data_log.count("ERROR")

        if err_coords != 0:
            msg_coord = chr(27)+"[1;31m"+"\nOne or more messages have incorrect data or missing keys\n"+chr(27)+"[0m"
        else:
            msg_coord = chr(27)+"[1;32m"+"\nEverythin OK with coordinates\n"+chr(27)+"[0m"

        if err_data != 0:
            msg_data = chr(27)+"[1;31m"+"\nOne or more messages have incorrect data or missing keys\n"+chr(27)+"[0m"
        else:
            msg_data = chr(27)+"[1;32m"+"\nEverythin OK with data values\n"\
                +chr(27)+"[0m"

        return msg_data,msg_coord

    def check_meta_grid(self):
        meta_log = list()
        grid_log = list()
        index = list()

        for i,msg in enumerate(self.grib_content):
            if "gridType" in msg.keys() and "GRIBEditionNumber" in msg and i==0:
                msg_edition = chr(27)+"[1;30m"+"Grib edition: "+chr(27)+"[0m"+str(msg["GRIBEditionNumber"])
                msg_gridtype = chr(27)+"[1;30m"+"Grid type: "+chr(27)+"[0m"+str(msg["gridType"])
                index.append(i)
                print(msg_edition)
                print(msg_gridtype)

            meta_log.append(metadata_checks.check_metada_keys(msg))
            grid_log.append(metadata_checks.check_grid_keys(msg))
        
        err_meta = meta_log.count("ERROR")
        err_grid = grid_log.count("ERROR")

        if err_meta != 0:
            msg_meta = chr(27)+"[1;31m"+"\nMetadata Check:\n\tOne or more messages have incorrect or missing KEYS\n"+chr(27)+"[0m"
        else:
            msg_meta = chr(27)+"[1;32m"+"\nMetadata Check:\n\tEverything OK\n"+chr(27)+"[0m"

        if err_grid != 0:
            msg_grid = chr(27)+"[1;31m"+"\nGrid Metada Check:\n\tOne or more messages have incorrect or missing Keys\n"+chr(27)+"[0m"
        else:
            msg_grid = chr(27)+"[1;32m"+"\nGrid Metada Check:\n\tEverything OK with data values\n"\
                +chr(27)+"[0m"

        return msg_meta,msg_grid

        # STILL WORKING ON THIS, and YES, I AM YELLING

if __name__ == "__main__":
    sys.exit()
